@@ -14,7 +14,7 @@ limitations under the License.
 
 import xml.etree.ElementTree as ET
 import os
-from warrior.Framework.Utils.print_Utils import print_info
+from warrior.Framework.Utils.print_Utils import print_debug
 from warrior.Framework.Utils import file_Utils
 from warrior.WarriorCore.Classes.html_results_class import WarriorHtmlResults
 from warrior.WarriorCore.Classes.execution_summary_class import ExecutionSummary
@@ -140,17 +140,17 @@ class Junit(object):
         self.add_property(name=kw_name, value="KEYWORD_DISCARD", elem_type="kw",
                           timestamp=tc_timestamp, keyword_items=keyword_items)
 
-    def add_testcase_message(self, timestamp, status, logs_dir=''):
+    def add_testcase_message(self, timestamp, status):
         """ Add a message element for fail/error/skip cases """
         elem = self.get_tc_with_timestamp(timestamp)
         if elem is None:
             elem = self.get_ts_with_timestamp(timestamp)
         if str(status).lower() == "false":
-            elem.append(self.create_element("failure", {"message": logs_dir}))
+            elem.append(self.create_element("failure", {"message": "test failure"}))
         elif str(status).lower() == "error":
             elem.append(self.create_element("error", {}))
         elif str(status).lower() == "skipped":
-            elem.append(self.create_element("skipped", {"message": logs_dir}))
+            elem.append(self.create_element("skipped", {}))
 
     def add_requirement(self, requirement, timestamp):
         """add a new requirement when called"""
@@ -251,12 +251,21 @@ class Junit(object):
         copy xslt to the results folder
         Print execution summary in console based on 'print_summary' value """
 
+        if print_summary is True:
+            fpath = path + os.sep + self.filename + "_junit.xml"
+            tree = ET.ElementTree(self.root)
+            tree.write(fpath)
+            summary_obj = ExecutionSummary(fpath)
+            summary_obj.print_result_in_console(fpath)
+        print_debug("\n")
+        if print_summary is True:
+            self._junit_to_html(fpath, print_summary)
+
+    def junit_output(self, path, print_summary=False):
+        """output the actual file
+        copy xslt to the results folder """
+
         fpath = path + os.sep + self.filename + "_junit.xml"
         tree = ET.ElementTree(self.root)
         tree.write(fpath)
-        if print_summary is True:
-            summary_obj = ExecutionSummary(fpath)
-            summary_obj.print_result_in_console(fpath)
-        print_info("\n")
-
         self._junit_to_html(fpath, print_summary)
