@@ -14,7 +14,7 @@ import inspect
 import traceback
 from warrior.Framework import Utils
 from warrior.Framework.Utils import data_Utils
-from warrior.Framework.Utils.print_Utils import print_info, print_error, print_exception
+from warrior.Framework.Utils.print_Utils import print_info, print_error, print_exception, print_debug
 from warrior.Framework.Utils.testcase_Utils import pNote_level
 from warrior.WarriorCore.Classes.war_cli_class import WarriorCliClass
 """Driver utils module which handles gathers the argument
@@ -205,7 +205,7 @@ class KeywordOperations(object):
             print_error("value for mandatory argument '{0}' not available in "
                         "data_repository/args_repository".format(args))
             return None
-        print_info("getting values for mandatory arguments")
+        print_debug("getting values for mandatory arguments")
         arg_kv = {}
         sysname = 'system_name'
         args_list = self.req_args_list[:]
@@ -232,7 +232,7 @@ class KeywordOperations(object):
     def get_values_for_optional_args(self, arg_kv):
         """The values for optional arguments as a python dictionary
         """
-        print_info("getting values for optional arguments")
+        print_debug("getting values for optional arguments")
         for args in self.optional_args_list:
             if args in self.args_repository:
                 arg_kv[args] = self.args_repository[args]
@@ -240,7 +240,7 @@ class KeywordOperations(object):
                 arg_kv[args] = self.data_repository[args]
             else:
                 arg_kv[args] = self.default_dict[args]
-                print_info("executing with default value '{0}' for optional "
+                print_debug("executing with default value '{0}' for optional "
                            "argument '{1}'".format(arg_kv[args], args))
         for args in self.optional_args_list:
             # requires another loop since system_name may not be at beginning
