@@ -243,10 +243,10 @@ def report_testcase_result(tc_status, data_repository, tag="Steps"):
         1. tc_status (bool) = status of the executed testcase
         2. data_repository (dict) = data_repository of the executed  testcase
     """
-    print_info("\n**** Testcase Result ***")
+    print_info("**** Testcase Result ***")
     print_info("TESTCASE:{0}  STATUS:{1}".format(data_repository['wt_name'],
                                                  convertLogic(tc_status)))
-    print_info("\n")
+    print_debug("\n")
     Utils.testcase_Utils.pTestResult(tc_status, data_repository['wt_resultfile'])
     root = Utils.xml_Utils.getRoot(data_repository['wt_resultfile'])
     fail_count = 0
@@ -334,7 +334,7 @@ def get_system_list(datafile, node_req=False, iter_req=False):
 def print_testcase_details_to_console(testcase_filepath, data_repository, steps_tag="Steps"):
     """Prints the testcase details to the console """
     framework_detail.warrior_framework_details()
-    print_info("\n===============================  TC-DETAILS  ===================================="
+    print_info("===============================  TC-DETAILS  ===================================="
                "==============")
     print_info("Title: %s" % data_repository['wt_title'])
     print_info("Results directory: %s" % data_repository['wt_resultsdir'])
@@ -404,7 +404,7 @@ def execute_steps(data_type, runtype, data_repository, step_list, tc_junit_objec
                                        data_repository, step_list)
     elif data_type.upper() == 'ITERATIVE' and \
                 runtype.upper() == 'SEQUENTIAL_KEYWORDS':
-        print_info("iterative sequential")
+        print_debug("iterative sequential")
         system_list = get_system_list(data_repository['wt_datafile'],\
                                           iter_req=True) \
             if iter_ts_sys is None else [iter_ts_sys]
@@ -422,7 +422,7 @@ def execute_steps(data_type, runtype, data_repository, step_list, tc_junit_objec
                 runtype.upper() == 'PARALLEL_KEYWORDS':
         tc_junit_object.remove_html_obj()
         data_repository["war_parallel"] = True
-        print_info("iterative parallel")
+        print_debug("iterative parallel")
         system_list = get_system_list(data_repository['wt_datafile'],\
                                           iter_req=True) \
         if iter_ts_sys is None else [iter_ts_sys]
@@ -437,7 +437,7 @@ def execute_steps(data_type, runtype, data_repository, step_list, tc_junit_objec
             tc_status = iterative_parallel_kw_driver.main(\
                  step_list, data_repository, tc_status, system_list)
     elif data_type.upper() == "HYBRID":
-        print_info("Hybrid")
+        print_debug("Hybrid")
         system_list, system_node_list = get_system_list(\
              data_repository['wt_datafile'], node_req=True)
             # call the hybrid driver here
@@ -694,9 +694,9 @@ def execute_testcase(testcase_filepath, data_repository, tc_context,
     defectsdir = data_repository['wt_defectsdir']
     check_and_create_defects(tc_status, auto_defects, data_repository, tc_junit_object)
 
-    print_info("\n")
+    print_debug("\n")
     tc_end_time = Utils.datetime_utils.get_current_timestamp()
-    print_info("[{0}] Testcase execution completed".format(tc_end_time))
+    print_debug("[{0}] Testcase execution completed".format(tc_end_time))
     tc_duration = Utils.datetime_utils.get_time_delta(tc_start_time)
     hms = Utils.datetime_utils.get_hms_for_seconds(tc_duration)
     print_info("Testcase duration= {0}".format(hms))
@@ -706,27 +706,7 @@ def execute_testcase(testcase_filepath, data_repository, tc_context,
     tc_junit_object.update_count("tests", "1", "pj", "not appicable")
     tc_junit_object.update_attr("status", str(tc_status), "tc", tc_timestamp)
     tc_junit_object.update_attr("time", str(tc_duration), "tc", tc_timestamp)
-    try:
-        files = []
-        logs_dir = data_repository['wt_logsdir']
-        for root, dirs, file_list in os.walk(logs_dir):
-            for file in file_list:
-                if 'consoleLog' in file: files.append(os.path.join(root, file))
-        for file in files:  console_log_file = file
-        job_url = os.getenv('JOB_URL')
-        if job_url:
-            job_base_name = os.getenv('JOB_BASE_NAME')
-            stage_name = os.getenv('STAGE_NAME')
-            build_url = os.getenv('BUILD_URL')
-            file_path = console_log_file.split(job_base_name, maxsplit=1)[1]
-            fail_msg = f'{build_url}execution/node/3/ws{file_path}' if stage_name else f'{job_url}ws{file_path}'
-            print_info("console_log_file:{}".format(fail_msg))
-        else:
-            fail_msg = "failure message"
-    except Exception as e:
-        print('Exception:', e)
-        fail_msg = 'failure message'
-    tc_junit_object.add_testcase_message(tc_timestamp, tc_status, fail_msg)
+    tc_junit_object.add_testcase_message(tc_timestamp, tc_status)
     if str(tc_status).upper() in ["FALSE", "ERROR", "EXCEPTION"]:
         tc_junit_object.update_attr("defects", defectsdir, "tc", tc_timestamp)
 
@@ -774,19 +754,19 @@ def execute_testcase(testcase_filepath, data_repository, tc_context,
                     value = item.text
                 data.update({item.tag: value})
 
-        ip_port = ["{}:{}".format(ip_address, ssh_port)]
-        data.update({"bootstrap_servers": ip_port})
-        data.update({"value_serializer": lambda x: json.dumps(x).encode('utf-8')})
-        try:
-            producer = WarriorKafkaProducer(**data)
-            producer.send_messages('warrior_results', suite_details.items())
-            producer.send_messages('warrior_results', test_case_details.items())
-            print_info("message published to topic: warrior_results {}".format(
-                suite_details.items()))
-            print_info("message published to topic: warrior_results {}".format(
-                test_case_details.items()))
-        except:
-            print_warning("Unable to connect kafka server !!")
+            ip_port = ["{}:{}".format(ip_address, ssh_port)]
+            data.update({"bootstrap_servers": ip_port})
+            data.update({"value_serializer": lambda x: json.dumps(x).encode('utf-8')})
+            try:
+                producer = WarriorKafkaProducer(**data)
+                producer.send_messages('warrior_results', suite_details.items())
+                producer.send_messages('warrior_results', test_case_details.items())
+                print_info("message published to topic: warrior_results {}".format(
+                    suite_details.items()))
+                print_info("message published to topic: warrior_results {}".format(
+                    test_case_details.items()))
+            except:
+                print_warning("Unable to connect kafka server !!")
 
     report_testcase_result(tc_status, data_repository, tag=steps_tag)
     if not from_ts:
